const SIGNATURE = '// generated by genversion'

exports.SIGNATURE = SIGNATURE

exports.createContent = (version, opts) => {
  // Create content for the version module
  //
  // Parameters:
  //   version: string, version tag
  //   opts: optional object with optional properties:
  //     useSemicolon:
  //       boolean. True to use semicolons in generated code
  //     useDoubleQuotes
  //       boolean. Set true to use double quotes in generated code
  //       instead of single quotes.
  //     useEs6Syntax:
  //       boolean. True to use ES6 export syntax in generated code
  //     useStrict:
  //       boolean. Add the 'use strict' header
  //
  // Return:
  //   string. The version module contents.
  //
  let content = SIGNATURE + '\n'

  const Q = opts.useDoubleQuotes ? '"' : '\''
  const SEMI = opts.useSemicolon ? ';' : ''

  // In some cases 'use strict' is required in the file
  // Can have comments before, but must be first statement
  if (opts.useStrict) {
    content += Q + 'use strict' + Q + SEMI + '\n\n'
  }

  if (opts.useEs6Syntax) {
    content += 'export const version'
  } else {
    content += 'module.exports'
  }

  content += ' = ' + Q + version + Q + SEMI + '\n'

  return content
}
